==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/tabs/translations/tabs_ca@valencia.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca@valencia">
<context>
    <name>@default</name>
    <message>
        <source>Tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Look</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move tab left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move tab right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch to previous tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch to next tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable tabs in chat window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>With this option, each chat will be opened in a separate tab in single window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Closing window closes current tab only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled, closing chat window will cause closing only current tab, instead of all tabs and the window itself</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tab bar position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose where you want the tab bar to be placed in chat window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reopen closed tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show &apos;Open chat&apos; button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show common &apos;Close Tab&apos; button on tab bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show &apos;Close&apos; button on each tab</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New message received, close window anyway?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recent Chats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Chat with...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TabsManager</name>
    <message>
        <source>Chat in New Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chat in New Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Attach Chat to Tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Detach</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Detach all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close other tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reopen closed tab</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/tabs/translations/tabs_ca@valencia.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca@valencia" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Tabs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Look</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Move tab left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Move tab right</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch to previous tab</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch to next tab</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable tabs in chat window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>With this option, each chat will be opened in a separate tab in single window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing window closes current tab only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>When enabled, closing chat window will cause closing only current tab, instead of all tabs and the window itself</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tab bar position</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Choose where you want the tab bar to be placed in chat window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Top</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bottom</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Behavior</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reopen closed tab</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show &apos;Open chat&apos; button</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show common &apos;Close Tab&apos; button on tab bar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show &apos;Close&apos; button on each tab</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New message received, close window anyway?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Recent Chats</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Chat with...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tabs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close Tab</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TabsManager</name>
    <message>
        <source>Chat in New Window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat in New Tab</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Attach Chat to Tabs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Detach</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Detach all</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close all</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close other tabs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reopen closed tab</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
